@@ -16,10 +16,11 @@ from .. import folder, server
 
 TIMEOUT = 120
 
+
 class TestRunServer(object):
     @classmethod
     def setup_class(cls):
-        cls.server_port = 33007 # just hope it's not taken
+        cls.server_port = 33007  # just hope it's not taken
 
         settings = Namespace()
         settings.port = cls.server_port
@@ -39,6 +40,7 @@ class TestRunServer(object):
         # instantly, but it's not bad to have an example of the pattern anyway.
         from requests.adapters import HTTPAdapter
         from requests.packages.urllib3.util.retry import Retry
+
         retry_strategy = Retry(
             total=10,
         )
@@ -48,17 +50,19 @@ class TestRunServer(object):
         cls.session.mount("http://", adapter)
 
     def test_wtml_rewrite(self):
-        base_url = 'http://localhost:{}/'.format(self.server_port)
+        base_url = "http://localhost:{}/".format(self.server_port)
 
         # More race condition mitigation
         for attempt in range(10):
             try:
-                f = folder.Folder.from_url(base_url + 'test1.wtml', timeout=TIMEOUT, session=self.session)
+                f = folder.Folder.from_url(
+                    base_url + "test1.wtml", timeout=TIMEOUT, session=self.session
+                )
                 break
             except requests.ConnectionError:
                 sleep(5)
 
-        assert f.children[0].thumbnail == base_url + 'thumb.jpg'
+        assert f.children[0].thumbnail == base_url + "thumb.jpg"
 
 
 class TestPreviewWtml(object):
@@ -70,17 +74,23 @@ class TestPreviewWtml(object):
     def setup_class(cls):
         cls.opened_url = None
 
-        # We should probably use a real Mock setup but ... meh.
         import webbrowser
-        def fake_open(url, **kwargs):
-            cls.opened_url = url
-        webbrowser.open = fake_open
+
+        class DummyBrowser(object):
+            def open(self, url, **kwargs):
+                cls.opened_url = url
+
+        webbrowser.register("wwtdummy", DummyBrowser)
 
         # Note: there can be a race condition between server startup and the
         # execution of the tests. There doesn't seem to be any mechanism to
         # enable the tests to rigorously wait for the server to be fully started
         # up.
-        cls.thread = Thread(target=lambda: server.preview_wtml(test_path('test1_rel.wtml')))
+        cls.thread = Thread(
+            target=lambda: server.preview_wtml(
+                test_path("test1_rel.wtml"), browser="wwtdummy"
+            )
+        )
         cls.thread.setDaemon(True)
         cls.thread.start()
 
@@ -90,6 +100,7 @@ class TestPreviewWtml(object):
         # instantly, but it's not bad to have an example of the pattern anyway.
         from requests.adapters import HTTPAdapter
         from requests.packages.urllib3.util.retry import Retry
+
         retry_strategy = Retry(
             total=10,
         )
@@ -104,13 +115,13 @@ class TestPreviewWtml(object):
                 break
             sleep(5)
 
-        assert '_rel' not in self.opened_url
+        assert "_rel" not in self.opened_url
 
 
 def test_smoke():
     """Dumb smoketest."""
 
-    server_address = ('', 0)
+    server_address = ("", 0)
 
     with HTTPServer(server_address, server.WWTRequestHandler) as httpd:
         pass
